@@ -19,6 +19,7 @@ class OutputFormat(str, Enum):
 
 class AFPQualityParameters(FormatterParameters):
     format: OutputFormat = Field(OutputFormat.xlsx, description="Output format")
+    text: bool = Field(True, description="Add text of document as separate sheet")
 
 
 class AFPQualityFormatter(FormatterBase):
@@ -56,6 +57,9 @@ class AFPQualityFormatter(FormatterBase):
             if parameters.format == OutputFormat.xlsx:
                 bio = io.BytesIO()
                 writer = pd.ExcelWriter(bio, engine='openpyxl')
+                if parameters.text:
+                    text_df = pd.DataFrame([document.text], columns=['Text'])
+                    text_df.to_excel(writer, index=False, sheet_name='text', columns=['Text'])
                 for subject, df in dfs.items():
                     df.to_excel(writer, index=False, sheet_name=subject, columns=['Code', 'Name', 'True', 'Pred'])
                 writer.save()
